============
Installation
============

At the command line::

    $ easy_install python-nameless

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv python-nameless
    $ pip install python-nameless